#!/usr/bin/php
<?php

function out($text) {
    print($text."\n");
}

// 'mogrify' and 'ffmpeg' are required for this script
// Run it by installing 'php' on Windows Subsystem for Linux

$scandir = scandir("./");
$images = [];
$sounds = [];
foreach ($scandir as $f) {
    if (preg_match("/^.*?@2x.(png|PNG)$/", $f)) {
        $images[] = $f;
    }
    if (preg_match("/^.*?.(mp3|wav)$/", $f)) {
        $sounds[] = $f;
    }
}
out("Found ".count($images)." @2x image files");
out("Found ".count($sounds)." MP3 and WAV audio files");

$i = 0;
$total = (count($images)+count($sounds));
foreach ($images as $f) {
    $newName = str_replace("@2x", "", $f);
    print("[".number_format(($i/$total)*100, 1)."%] Creating $newName: ");
    copy($f, $newName);
    exec("mogrify -strip -resize 50% '$newName'", $out);
    print("Done\n");
    $i++;
}
$errors = [];
foreach ($sounds as $f) {
    $newName = str_replace([".wav", ".mp3"], ".ogg", $f);
    print("[".number_format(($i/$total)*100, 1)."%] Creating $newName: ");
    // Delete new .ogg file if it exists
    if (file_exists($newName)) unlink($newName);
    // Convert the mp3/wav file to ogg
    $time = time();
    exec("ffmpeg -hide_banner -loglevel error -i '$f' '$newName'", $out);
    if ((time()-$time) > 5) $errors[] = $f;
    // Delete the old file if the new one exists
    if (file_exists($newName)) unlink($f);
    print("Done\n");
    $i++;
}
if (count($errors) > 0) {
    out("FFMPEG ran for more than 5 seconds while converting these files:");
    foreach ($errors as $e) {
        out(" - $e");
    }
}

?>